package com.jdcity.jzt.bkuser.common.utils;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtBuilder;
import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;
import java.util.Date;
import javax.crypto.spec.SecretKeySpec;
import javax.xml.bind.DatatypeConverter;

public class JWT {

   private static final String KEY = "JztBkUserKey";


   public static String createJWT(String id, String issuer, String subject, long ttlMillis, String audience) {
      SignatureAlgorithm signatureAlgorithm = SignatureAlgorithm.HS256;
      long nowMillis = System.currentTimeMillis();
      Date now = new Date(nowMillis);
      byte[] apiKeySecretBytes = DatatypeConverter.parseBase64Binary("JztBkUserKey");
      SecretKeySpec signingKey = new SecretKeySpec(apiKeySecretBytes, signatureAlgorithm.getJcaName());
      JwtBuilder jwtBuilder = Jwts.builder().setId(id).setSubject(subject).setIssuedAt(now).setIssuer(issuer).setAudience(audience).signWith(signatureAlgorithm, signingKey);
      if(ttlMillis >= 0L) {
         long expMillis = nowMillis + ttlMillis;
         Date exp = new Date(expMillis);
         jwtBuilder.setExpiration(exp);
      }

      return jwtBuilder.compact();
   }

   public static Claims getClaims(String jwt) {
      return (Claims)Jwts.parser().setSigningKey(DatatypeConverter.parseBase64Binary("JztBkUserKey")).parseClaimsJws(jwt).getBody();
   }

   public static String createJwtId(String uuid, String ticket) {
      return uuid + "#" + ticket;
   }

   public static void main(String[] args) {
      String userId = "WKSH121321KKsdfk";
      String issuer = "http://www.jd.com";
      String subject = "www.JD.com";
      long ttlMillis = 60000L;
      String audience = "FESCO-APP";
      String token = createJWT(userId, issuer, subject, -1L, audience);
      System.out.println(token);
      Claims claims = getClaims(token);
      System.out.println("---------------------------解密的token信息----------------------------------");
      System.out.println("ID: " + claims.getId());
      System.out.println("Subject: " + claims.getSubject());
      System.out.println("Issuer: " + claims.getIssuer());
      System.out.println("Expiration: " + claims.getExpiration());
   }
}
